==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/GetRegistryEnvironmentVersionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.GetRegistryEnvironmentVersionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property environmentName Container name. This is case-sensitive.
 * @property registryName Name of Azure Machine Learning registry. This is case-insensitive
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property version Version identifier. This is case-sensitive.
 */
public data class GetRegistryEnvironmentVersionPlainArgs(
    public val environmentName: String,
    public val registryName: String,
    public val resourceGroupName: String,
    public val version: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.GetRegistryEnvironmentVersionPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.GetRegistryEnvironmentVersionPlainArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.GetRegistryEnvironmentVersionPlainArgs.builder()
            .environmentName(environmentName.let({ args0 -> args0 }))
            .registryName(registryName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .version(version.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetRegistryEnvironmentVersionPlainArgs].
 */
@PulumiTagMarker
public class GetRegistryEnvironmentVersionPlainArgsBuilder internal constructor() {
    private var environmentName: String? = null

    private var registryName: String? = null

    private var resourceGroupName: String? = null

    private var version: String? = null

    /**
     * @param value Container name. This is case-sensitive.
     */
    @JvmName("qbmetjbdssujowuw")
    public suspend fun environmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentName = mapped
    }

    /**
     * @param value Name of Azure Machine Learning registry. This is case-insensitive
     */
    @JvmName("vaylujkdxcbxwhlq")
    public suspend fun registryName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.registryName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("rbfhhqwyhfjlacrk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Version identifier. This is case-sensitive.
     */
    @JvmName("rpgkhyllpesfvjgd")
    public suspend fun version(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.version = mapped
    }

    internal fun build(): GetRegistryEnvironmentVersionPlainArgs =
        GetRegistryEnvironmentVersionPlainArgs(
            environmentName = environmentName ?: throw PulumiNullFieldException("environmentName"),
            registryName = registryName ?: throw PulumiNullFieldException("registryName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            version = version ?: throw PulumiNullFieldException("version"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/GetRegistryEnvironmentVersionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.GetRegistryEnvironmentVersionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property environmentName Container name. This is case-sensitive.
 * @property registryName Name of Azure Machine Learning registry. This is case-insensitive
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property version Version identifier. This is case-sensitive.
 */
public data class GetRegistryEnvironmentVersionPlainArgs(
    public val environmentName: String,
    public val registryName: String,
    public val resourceGroupName: String,
    public val version: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.GetRegistryEnvironmentVersionPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.GetRegistryEnvironmentVersionPlainArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.GetRegistryEnvironmentVersionPlainArgs.builder()
            .environmentName(environmentName.let({ args0 -> args0 }))
            .registryName(registryName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .version(version.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetRegistryEnvironmentVersionPlainArgs].
 */
@PulumiTagMarker
public class GetRegistryEnvironmentVersionPlainArgsBuilder internal constructor() {
    private var environmentName: String? = null

    private var registryName: String? = null

    private var resourceGroupName: String? = null

    private var version: String? = null

    /**
     * @param value Container name. This is case-sensitive.
     */
    @JvmName("iqdwepgfosfqtcip")
    public suspend fun environmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentName = mapped
    }

    /**
     * @param value Name of Azure Machine Learning registry. This is case-insensitive
     */
    @JvmName("ougdmhprheyufbqh")
    public suspend fun registryName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.registryName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mcewrtcwfqbyufmu")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Version identifier. This is case-sensitive.
     */
    @JvmName("nhnxkyimklwjotfh")
    public suspend fun version(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.version = mapped
    }

    internal fun build(): GetRegistryEnvironmentVersionPlainArgs =
        GetRegistryEnvironmentVersionPlainArgs(
            environmentName = environmentName ?: throw PulumiNullFieldException("environmentName"),
            registryName = registryName ?: throw PulumiNullFieldException("registryName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            version = version ?: throw PulumiNullFieldException("version"),
        )
}
